@@ -104,7 +104,7 @@ class BackupTest(BaseTest):
         os.chmod(self.rootdir, stat.S_IRUSR | stat.S_IXUSR)
         app = self.cmd("--backup")
         with self.new_files(False):
-            window = app.window("Back Up")
+            window = self.get_dialog(app)
             window.button("Forward").click()  # folders
             window.button("Forward").click()  # storage location
             window.childNamed("Backup Failed")
@@ -140,7 +140,7 @@ class BackupTest(BaseTest):
 
         app = self.cmd("--backup")
         with self.new_files():
-            window = app.window("Computer name changed")
+            window = self.get_dialog(app)
             window.button("Forward").click()
             self.walk_incremental_backup(app)
 
@@ -171,7 +171,7 @@ class BackupTest(BaseTest):
         with self.new_files():
             self.wait_for(mid_progress)
             sleep(0.2)  # give time for duplicity to write a .part file
-            app.button("Resume Later").click()
+            app.button("Pause").click()
             self.wait_for(lambda: window.dead)
 
         assert last_backup == self.get_string("last-backup")
@@ -223,7 +223,7 @@ class BackupTest(BaseTest):
 
         # One backup just to confirm we don't need password
         app = self.cmd("--backup")
-        self.walk_incremental_backup(app)
+        self.walk_incremental_backup(app, password=None)
 
         months_ago = GLib.DateTime.new_now_utc().add_days(-60).format_iso8601()
         self.set_string("nag-check", months_ago)
@@ -255,10 +255,6 @@ class ResticBackupTest(ResticMixin, BackupTest):
     def test_resume(self, initial):
         super().test_resume(initial)
 
-    @expectedFailure  # verify support isn't finished yet
-    def test_nag_check(self):
-        super().test_nag_check()
-
     @skip("hostname question doesn't exist in restic")
     def test_hostname_question(self):
         super().test_hostname_question()
