@@ -6,7 +6,9 @@
 
 import os
 import shutil
+import socket
 import stat
+from unittest import mock
 
 from dogtail.predicate import GenericPredicate
 from dogtail.rawinput import holdKey, keyCombo, pressKey, releaseKey, typeText
@@ -34,7 +36,8 @@ class BrowserTest(BaseTest):
         basedir = os.path.realpath(os.path.join(os.path.dirname(__file__)))
         srcfiles = basedir + "/" + path
 
-        backupdir = "/tmp/deja-dup.backup"
+        backupdir = GLib.get_home_dir() + "/.deja-dup-test/dest"
+        os.makedirs(backupdir, exist_ok=True)
         shutil.rmtree(backupdir, ignore_errors=True)
         shutil.copytree(srcfiles, backupdir, ignore=shutil.ignore_patterns("*.license"))
         self.set_string("folder", backupdir, child="local")
@@ -96,13 +99,33 @@ class BrowserTest(BaseTest):
         self.scan()
         self.snapshots = ["06/07/20 09:33:07", "06/07/20 09:29:40", "06/04/20"]
 
+    def scan_dir3(self):
+        """
+        Set up third backup directory.
+
+        This one emulates switching home dirs.
+
+        The most recent snapshot should contain:
+          /home/_not-a-user_/.deja-dup-test/src/docs/1.txt ("1")
+          /home/_not-a-user_/.deja-dup-test/src/docs/subdir/2.txt ("2")
+
+        We use so many subdirs so that we can safely restore to the original
+        location while also swapping out the 'src' dir with a symlink that
+        points to a different dir (to simulate Fedora Silverblue symlinked
+        home dirs)
+        """
+        self.password = "t"
+        self.use_backup_dir("duplicity3")
+        self.scan()
+
     def assert_search_mode(self, searching=True):
         search = self.app.child(roleName="toggle button", name="Search")
         assert search.pressed == searching
 
         search_entry = self.app.findChild(
             GenericPredicate(roleName="entry", name="Search"),
-            retry=False, requireResult=False,
+            retry=False,
+            requireResult=False,
         )
         if searching:
             assert search_entry and search_entry.focused
@@ -123,14 +146,14 @@ class BrowserTest(BaseTest):
 
     def start_restore(self):
         self.click_restore_button(self.app)
-        self.window = self.app.window("Restore to Where?")
+        self.window = self.get_dialog(self.app)
 
     def select_location(self, where):
         self.addCleanup(shutil.rmtree, where, ignore_errors=True)
         self.window.child(
             roleName="list item", name="Restore to specific folder"
         ).click()
-        self.window.child(roleName="push button", name="Choose Folder").click()
+        self.window.child(roleName="button", name="Choose Folder").click()
         os.makedirs(where, exist_ok=True)
         dlg = self.get_file_chooser("Select a Folder")
         typeText(where + "\n")
@@ -146,9 +169,9 @@ class BrowserTest(BaseTest):
         self.window.button("Restore").click()  # to where
 
         if self.password:
-            self.window.child(
-                roleName="text", label="Encryption password"
-            ).text = self.password
+            self.window.child(roleName="text", label="Encryption password").text = (
+                self.password
+            )
             self.window.button("Forward").click()
 
         title = "Restore Failed" if error else "Restore Finished"
@@ -191,6 +214,9 @@ class BrowserTest(BaseTest):
             holdKey("Control_L")
             child.click()
             releaseKey("Control_L")
+            if on != child.selected:
+                # Try harder
+                keyCombo("space")
 
     def test_enable_search_mode(self):
         self.scan_dir1()
@@ -212,8 +238,7 @@ class BrowserTest(BaseTest):
         icons = restore_panel.findChildren(lambda x: x.roleName == "table cell")
         assert len(icons) == 4 and len([i for i in icons if i.selected]) == 0
 
-        self.app.childNamed("Main Menu").click()
-        self.app.childNamed("Select All").click()
+        keyCombo("<Control>a")
 
         assert len([i for i in icons if i.selected]) == 4
 
@@ -243,7 +268,7 @@ class BrowserTest(BaseTest):
 
         # test dir navigation (could go in any test, but thrown in here)
         view = self.app.child(roleName="table")
-        back = self.app.child(roleName="push button", name="Back")
+        back = self.app.child(roleName="button", name="Back")
         assert not back.sensitive
         assert len(view.children) == 3
         dir1 = view.child(roleName="label", name="dir1")
@@ -264,7 +289,7 @@ class BrowserTest(BaseTest):
                 lambda x: x.roleName == "label", showingOnly=False
             )
         ]
-        assert self.snapshots == dates
+        assert self.snapshots == dates, dates
 
         # choose oldest date, it should have an extra item in it
         pressKey("Down")
@@ -275,7 +300,7 @@ class BrowserTest(BaseTest):
         assert len(view.children) == 4
 
     def test_scan_error(self):
-        self.set_string("folder", "/tmp/deja-dup.missing", child="local")
+        self.set_string("folder", GLib.get_home_dir() + "/.deja-dup-test/missing", child="local")
         self.scan(error="No backup files found")
 
     def test_bad_restore_permissions(self):
@@ -314,6 +339,17 @@ class BrowserTest(BaseTest):
 
         self.window.button("Cancel").click()
 
+    def test_moved_home(self):
+        # Set up a symlink path (to simulate Fedora Silverblue symlinked home)
+        self.srcdir = self.rootdir + "/src/docs"
+        os.makedirs(self.rootdir + "/deeper/src", exist_ok=True)
+        os.symlink("deeper/src", self.rootdir + "/src", target_is_directory=True)
+
+        self.scan_dir3()
+        self.select("1.txt", "subdir")
+        self.walk_restore()
+        self.check_files(("1.txt", "1"), ("subdir/2.txt", "2"))
+
 
 class ResticBrowserTest(ResticMixin, BrowserTest):
     def scan_dir1(self):
@@ -325,4 +361,17 @@ class ResticBrowserTest(ResticMixin, BrowserTest):
         self.password = "test2"
         self.use_backup_dir("restic2")
         self.scan()
-        self.snapshots = ["08/02/21 15:34:06", "08/02/21 15:33:43", "07/28/21"]
+        hostname = socket.gethostname()
+        if hostname != "tama":
+            self.snapshots = [
+                "08/02/21 15:34:06 (tama)",
+                "08/02/21 15:33:43 (tama)",
+                "07/28/21 (tama)",
+            ]
+        else:
+            self.snapshots = ["08/02/21 15:34:06", "08/02/21 15:33:43", "07/28/21"]
+
+    def scan_dir3(self):
+        self.password = "t"
+        self.use_backup_dir("restic3")
+        self.scan()
