@@ -8,6 +8,7 @@ import glob
 import os
 
 from dogtail import tree
+from dogtail.rawinput import keyCombo
 from gi.repository import Gio, GLib, Gtk
 
 from . import BaseTest
@@ -20,16 +21,15 @@ class IntegrationTest(BaseTest):
             self.skipTest("dev mode")
 
     def test_translations(self):
-        app = self.cmd(env="LANG=fr_FR.UTF-8 LANGUAGE=fr")
+        app = self.cmd(env="LC_ALL=fr_FR.UTF-8 LANGUAGE=fr")
         assert app.childNamed("Restaurer")
 
     def test_help(self):
-        # Also test that help is translated by passing LANG
-        app = self.cmd(env="LANG=fr_FR.UTF-8 LANGUAGE=fr")
+        app = self.cmd(env="LC_ALL=fr_FR.UTF-8 LANGUAGE=fr")
         app.childNamed("Menu principal").click()
 
         self.addCleanup(self.kill_bus, "org.gnome.Yelp")
-        app.child(roleName="menu item", name="Aide").click()
+        keyCombo("F1")
 
         yelp = tree.root.application("yelp")
         assert yelp.childNamed("Sauvegarder")
