@@ -9,6 +9,7 @@ import shutil
 from datetime import datetime
 
 from dogtail.predicate import GenericPredicate
+from dogtail.rawinput import keyCombo
 from gi.repository import GLib
 
 from . import BaseTest, ResticMixin
@@ -27,12 +28,12 @@ class RestoreTest(BaseTest):
         open(self.filename, "w").write(self.contents)
 
     def walk_backup(self, app):
-        window = app.window("Back Up")
+        window = self.get_dialog(app)
         window.button("Forward").click()  # folders
         window.button("Forward").click()  # storage location
 
         self.wait_for(
-            lambda: lambda: window.findChild(
+            lambda: window.findChild(
                 GenericPredicate(roleName="text", label="Encryption password"),
                 retry=False,
                 requireResult=False,
@@ -51,12 +52,12 @@ class RestoreTest(BaseTest):
             confirm.text = "test-restore"
 
         window.button("Forward").click()
-        self.wait_for(lambda: window.dead, timeout=300)
+        self.wait_for(lambda: window.dead, timeout=600)
 
     def walk_restore(self, app):
         shutil.rmtree(self.srcdir)
 
-        window = app.window("Restore From Where?")
+        window = self.get_dialog(app)
         window.button("Search").click()  # from where
         search = app.child(roleName="toggle button", name="Search")
 
@@ -67,14 +68,21 @@ class RestoreTest(BaseTest):
 
         # Now select all.
         self.wait_for(lambda: search.sensitive, timeout=300)
-        app.childNamed("Main Menu").click()
-        app.childNamed("Select All").click()
+        keyCombo("<Control>a")
 
         # And start restore
         self.click_restore_button(app)
-        window = app.window("Restore to Where?")
+        window = self.get_dialog(app)
         window.button("Restore").click()  # to where
 
+        self.wait_for(
+            lambda: window.findChild(
+                GenericPredicate(roleName="text", label="Encryption password"),
+                retry=False,
+                requireResult=False,
+            ),
+            timeout=600,
+        )
         window.child(roleName="text", label="Encryption password").text = "test-restore"
         window.button("Forward").click()
 
@@ -83,7 +91,7 @@ class RestoreTest(BaseTest):
             lambda: window.findChild(
                 GenericPredicate(name=title), retry=False, requireResult=False
             ),
-            timeout=60,
+            timeout=600,
         )
         window.button("Close").click()
 
@@ -165,3 +173,19 @@ class ResticRemoteRestoreTest(ResticMixin, RemoteRestoreTest):
     def setUp(self):
         super().setUp()
         self.set_string("folder", self.folder + "-restic", child="remote")
+
+
+class RcloneRestoreTest(RestoreTest):
+    __test__ = True
+
+    def setUp(self):
+        super().setUp()
+        self.set_string("backend", "rclone")
+        self.set_string("remote", ":local", child="rclone")
+        self.set_string("folder", self.rootdir + "/dest", child="rclone")
+
+
+class ResticRcloneRestoreTest(ResticMixin, RcloneRestoreTest):
+    def setUp(self):
+        super().setUp()
+        self.set_string("folder", self.rootdir + "/dest-restic", child="rclone")
