@@ -17,15 +17,14 @@ class PreferencesTest(BaseTest):
     def setUp(self):
         super().setUp()
         self.app = self.cmd()
-        self.app.child(name="Main Menu").click()
-        self.app.childNamed("Preferences").click()
+        keyCombo("<Control>comma")
 
     def get_auto_check(self, root):
         box = root.child(roleName="list item", name="Back Up Automatically")
         return box.child(roleName="check box")
 
     def get_preferences_window(self):
-        return self.app.child(roleName="frame", name="Preferences")
+        return self.get_dialog(self.app)
 
     def test_general(self):
         # Test that there's a special first time welcome screen
@@ -56,6 +55,10 @@ class PreferencesTest(BaseTest):
         self.wait_for(lambda: self.refresh(periodic).checked)
         self.wait_for(lambda: self.refresh(periodic_main).checked)
 
+        # Scroll to bottom
+        scrollbar = prefs.child(roleName="scroll bar")
+        scrollbar.node.value = 100
+
         # Period to settings
         period = prefs.child(roleName="combo box", name="Automatic Backup Frequency")
         period.click()
@@ -88,7 +91,7 @@ class PreferencesTest(BaseTest):
         table = self.refresh(table)
 
         def iter(x):
-            return x.roleName == "label" and x.name
+            return x.roleName == "label" and not x.name.startswith("Add")
 
         objs = table.findChildren(iter, showingOnly=False)
         return [x.name for x in objs]
@@ -96,7 +99,7 @@ class PreferencesTest(BaseTest):
     def wait_for_table_names(self, table, names):
         self.wait_for(lambda: self.table_names(table) == names)
 
-    def assert_inclusion_table(self, widget, key):
+    def assert_inclusion_table(self, widget, add_label, key):
         prefs = self.get_preferences_window()
         prefs.child(roleName="page tab", name="Folders").click()
 
@@ -142,7 +145,7 @@ class PreferencesTest(BaseTest):
 
         # Remove most
         def remove_buttons(x):
-            return x.roleName == "push button" and x.name == "Remove"
+            return x.roleName == "button" and x.name == "Remove"
 
         count = len(labels)
         for i in range(len(labels) - 1):
@@ -151,7 +154,7 @@ class PreferencesTest(BaseTest):
         self.assertEqual(self.get_strv(key), ["$PICTURES"])
 
         # Add one
-        add = table.child(name="Add")
+        add = table.child(name=add_label)
         add.click()
         dlg = self.get_file_chooser("Select Folders")
         typeText(home + "/Documents\n")
@@ -159,7 +162,15 @@ class PreferencesTest(BaseTest):
         self.assertEqual(self.get_strv(key), ["$PICTURES", home + "/Documents"])
 
     def test_includes(self):
-        self.assert_inclusion_table("Folders to Back Up", "include-list")
+        self.assert_inclusion_table(
+            "Folders to Back Up",
+            "Add Backed Up Folder…",
+            "include-list",
+        )
 
     def test_excludes(self):
-        self.assert_inclusion_table("Folders to Ignore", "exclude-list")
+        self.assert_inclusion_table(
+            "Folders to Ignore",
+            "Add Ignored Folder…",
+            "exclude-list",
+        )
